@@ -1,5 +1,9 @@
+#ifndef _FISHER_H
+#define _FISHER_H
 
 double bilateral(double a, double b, double c, double d);
 double right(double a, double b, double c, double d);
 double left(double a, double b, double c, double d);
 
+#endif
+
